==> haskell-monad-logger-0.3.42-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-DzuvouqTXPc2PHdHITihdp
key:                  monad-logger-0.3.42-DzuvouqTXPc2PHdHITihdp
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  37e93011b10c12b99f8cdf1f126fdfba
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-DzuvouqTXPc2PHdHITihdp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-3OoOkivWqZS7dcQwoEFiHk
    conduit-extra-1.3.8-BJDq9IUY40K5dXgPcvjS82 exceptions-0.10.5
    fast-logger-3.2.4-BpzBlTxgS5DB3J0en1gevm
    lifted-base-0.2.3.12-K95KhxsU62vCEfDwRWfqIf
    monad-control-1.0.3.1-F7OGpFtdcoIGnChB30cAbG
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-DmwxA4NFPQTJ3BdeBVaPkm stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-2uAlFN9wTx3C7pJQeXk7KL
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.42-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-GNqCUtWAO2Q2C8T1VJiUfn
key:                  monad-logger-0.3.42-GNqCUtWAO2Q2C8T1VJiUfn
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  9a3f9a6f60cff41c44a5557f0f3a9269
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-GNqCUtWAO2Q2C8T1VJiUfn
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-LOP5sjciwZZGtwvmGKv7ZW
    conduit-extra-1.3.8-1JMiFOCwvslD8QGjqNo8o8 exceptions-0.10.5
    fast-logger-3.2.4-7XwUX0NOhm7HKGD1lYGUb4
    lifted-base-0.2.3.12-4SjQ97Z1EZO7u8bS3zrpFZ
    monad-control-1.0.3.1-KMMsUvpItyN2wbHnTJnKnA
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    resourcet-1.2.6-9cm9lWfgO5WKiqJck5h8fE stm-2.5.1.0
    stm-chans-3.0.0.9-CQu29so2bvC6Kzm6cIERmj template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-2BDDnVZ1JKvI3S6fEBZY2Y
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
